%define uname	Eigen3

Name:		eigen3
Summary:	Lightweight C++ template library for vector and matrix math
Version:	3.4.0
Release:	%mkrel 4
Group:		System/Libraries
License:	LGPLv3+ or GPLv2+
URL:		https://eigen.tuxfamily.org/
Source0:	https://gitlab.com/libeigen/eigen/-/archive/%{version}/eigen-%{version}.tar.bz2
Source1:	%{name}.png

BuildRequires:	cmake
BuildRequires:	doxygen
BuildRequires:	ghostscript-common
BuildRequires:	graphviz
BuildRequires:	tetex-dvips
BuildRequires:	tetex-latex
BuildRequires:	gmp-devel
BuildRequires:	qt4-devel
BuildRequires:	suitesparse-devel
BuildRequires:	pkgconfig(freeglut)
BuildRequires:	pkgconfig(xmu)
BuildRequires:	pkgconfig(libsparsehash)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(mpfr)
# (tmb) test youri
BuildArch:	noarch

%description
Eigen is a lightweight C++ template library for vector and matrix
math, a.k.a. linear algebra.

%package devel
Summary:	Header files for %{uname}
BuildArch:	noarch

%description devel
Eigen is a lightweight C++ template library for vector and matrix
math, a.k.a. linear algebra.

%package doc
Summary:	This is the API documentation for %{uname}
BuildArch:	noarch

%description  doc
This is the API documentation for %{uname}.

%prep
%autosetup -p1 -n eigen-%{version}

%build
export CXXFLAGS="%{optflags} -fpermissive -Wno-int-in-bool-context"
export CFLAGS="%{optflags} -fpermissive -Wno-int-in-bool-context"

%cmake

%cmake_build

%cmake_build --target doc

%install
%cmake_install

install -d %{buildroot}%{_docdir}/%{name}/html
cp -r %{_vpath_builddir}/doc/html/* %{buildroot}%{_docdir}/%{name}/html

# Desktop
install -d %{buildroot}%{_datadir}/applications
install -d %{buildroot}%{_iconsdir}
install -D %{SOURCE1} %{buildroot}%{_iconsdir}
cat > %{buildroot}%{_datadir}/applications/%{name}-doc.desktop << EOF
[Desktop Entry]
Name=%{uname} C++ API Documentation
GenericName=%{uname} C++ API Documentation
Exec=xdg-open %{_docdir}/%{name}/html/index.html
Icon=%{name}
Terminal=false
Type=Application
Categories=System;Documentation;X-Mageia-CrossDesktop;
X-Desktop-File-Install-Version=0.19
EOF

%pretrans devel -p <lua>
path = "%{_includedir}/eigen3/Eigen"
st = posix.stat(path)
if st and st.type == "directory" then
  os.execute("rm -rf " .. path)
end
path = "%{_includedir}/Eigen"
st = posix.stat(path)
if st and st.type == "link" then
  os.execute("rm -rf " .. path)
end

%files doc
%doc %{_docdir}/*
%{_datadir}/applications/%{name}-doc.desktop
%{_iconsdir}/*

%files devel
%{_includedir}/signature_of_%{name}_matrix_library
%dir %{_includedir}/unsupported
%{_includedir}/unsupported/Eigen/
%{_includedir}/Eigen/
%{_datadir}/pkgconfig/%{name}.pc
%{_datadir}/%{name}/


%changelog
* Thu May 04 2023 daviddavid <daviddavid> 3.4.0-4.mga9
+ Revision: 1955796
- fix owner of include dir

* Sun Apr 03 2022 umeabot <umeabot> 3.4.0-3.mga9
+ Revision: 1841496
- Mageia 9 Mass Rebuild

* Wed Sep 15 2021 barjac <barjac> 3.4.0-2.mga9
+ Revision: 1745544
- Fix update from Mga8

* Wed Sep 15 2021 barjac <barjac> 3.4.0-1.mga9
+ Revision: 1745475
- new version 3.4.0
- Dont interfere with %%cmake to fix build
- Remove unneeded backward compatability link
- Fix %%files lists and some ownerships

* Wed Dec 09 2020 barjac <barjac> 3.3.9-1.mga8
+ Revision: 1654988
- new version 3.3.9
  remove patch

* Sat Oct 10 2020 joequant <joequant> 3.3.8-4.mga8
+ Revision: 1633134
- add fix for backward compatibility for file locations

* Sat Oct 10 2020 barjac <barjac> 3.3.8-3.mga8
+ Revision: 1633113
- fix upgrade path
- patch for blender build issue
- revert previous commit

* Fri Oct 09 2020 barjac <barjac> 3.3.8-2.mga8
+ Revision: 1633001
- Add conflict due to file type change

* Thu Oct 08 2020 barjac <barjac> 3.3.8-1.mga8
+ Revision: 1632881
- new version 3.3.8
- new source0 (gitlab)
- new options to cmake
- some new file paths
- no need for githash or debug_package %%{nil}

* Sat Aug 15 2020 wally <wally> 3.3.7-3.mga8
+ Revision: 1614108
- fix doc build
- drop version string from docs .desktop file

* Sat Feb 15 2020 daviddavid <daviddavid> 3.3.7-2.mga8
+ Revision: 1526574
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Wed Dec 12 2018 daviddavid <daviddavid> 3.3.7-1.mga7
+ Revision: 1340395
- new version: 3.3.7
- new version: 3.3.6

* Thu Sep 20 2018 umeabot <umeabot> 3.3.4-2.mga7
+ Revision: 1278060
- Mageia 7 Mass Rebuild

* Tue Dec 19 2017 barjac <barjac> 3.3.4-1.mga7
+ Revision: 1183499
- new version 3.3.4
- dont run %%check as it creates over 1GB of logs and fails are expected

* Thu Apr 13 2017 pterjan <pterjan> 3.3.3-3.mga7
+ Revision: 1096512
- Also do tests in parallel
- Build the doc in parallel, it currently wastes hours using only one core

* Sat Mar 11 2017 wally <wally> 3.3.3-2.mga6
+ Revision: 1091999
- fix compiler flags
- add %%pretrans lua scriptlet to fix update from mga5 (mga#20448)

* Tue Feb 28 2017 barjac <barjac> 3.3.3-1.mga6
+ Revision: 1088198
- new release 3.3.3

* Mon Jan 30 2017 barjac <barjac> 3.3.2-1.mga6
+ Revision: 1084294
- new version 3.3.2
- tidy some strings in spec
- fix files list

* Thu Sep 29 2016 neoclust <neoclust> 3.2.9-3.mga6
+ Revision: 1057497
- Fix link

* Wed Sep 28 2016 neoclust <neoclust> 3.2.9-2.mga6
+ Revision: 1057240
- Try to help to fix scilab build

* Tue Jul 26 2016 barjac <barjac> 3.2.9-1.mga6
+ Revision: 1043641
- new maintainence bug fix version 3.2.9

* Fri Feb 19 2016 barjac <barjac> 3.2.8-1.mga6
+ Revision: 968799
- new version 3.2.8
- enable tests but dont let fails break build

* Wed Dec 09 2015 barjac <barjac> 3.2.7-1.mga6
+ Revision: 909230
- new version 3.2.7

* Fri Oct 02 2015 tmb <tmb> 3.2.5-4.mga6
+ Revision: 885744
- try to get past youri
+ barjac <barjac>
- Bump rel and re-submit as BS failed for no obvious reason
- new version 3.2.5
+ neoclust <neoclust>
- Fix build with new rpm ( empty debuginfo)

* Sat Aug 29 2015 daviddavid <daviddavid> 3.2.2-4.mga6
+ Revision: 871076
- rebuild with gcc 5.2.1

* Wed Oct 15 2014 umeabot <umeabot> 3.2.2-3.mga5
+ Revision: 745891
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2.2-2.mga5
+ Revision: 678980
- Mageia 5 Mass Rebuild

* Wed Aug 06 2014 barjac <barjac> 3.2.2-1.mga5
+ Revision: 660169
- new version eigen3-3.2.2

* Sat Mar 15 2014 barjac <barjac> 3.2.1-1.mga5
+ Revision: 603979
- fix versioning

* Tue Mar 11 2014 barjac <barjac> 3.2-4.mga5
+ Revision: 601995
- new minor bugfix release

* Mon Oct 28 2013 barjac <barjac> 3.2-3.mga4
+ Revision: 547615
- changed buildrequires
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild
+ fwang <fwang>
- br glut

* Tue Aug 06 2013 fwang <fwang> 3.2-1.mga4
+ Revision: 464098
- new version 3.2

* Mon Jun 10 2013 barjac <barjac> 3.1.3-1.mga4
+ Revision: 441883
- new version 3.1.3

* Fri Jan 11 2013 umeabot <umeabot> 3.1.2-2.mga3
+ Revision: 349577
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 barjac <barjac> 3.1.2-1.mga3
+ Revision: 340260
- new version
- two new build requires
+ joequant <joequant>
- upgrade to 3.1.1

* Tue Jul 10 2012 fwang <fwang> 3.0.6-1.mga3
+ Revision: 269161
- new version 3.0.6

* Tue Feb 28 2012 barjac <barjac> 3.0.5-2.mga2
+ Revision: 215941
+ rebuild (emptylog)

* Tue Feb 28 2012 barjac <barjac> 3.0.5-1.mga2
+ Revision: 215934
- Main package now -devel
- Corrected doc dir ownership
- imported package eigen3

